@@ -16,11 +16,11 @@
 import json
 import logging
 import os
-import subprocess
 import sys
 
-from subiquitycore.controllers.identity import BaseIdentityController
-from subiquitycore.utils import disable_first_boot_service, run_command
+from subiquitycore.controller import BaseController
+from subiquitycore.models import IdentityModel
+from subiquitycore.utils import disable_console_conf, run_command
 
 from console_conf.ui.views import IdentityView, LoginView
 
@@ -46,42 +46,82 @@ def get_device_owner():
             return result
     return None
 
-login_details_tmpl = """\
-Congratulations! This device is now registered to {realname}.
+def host_key_fingerprints():
+    """Query sshd to find the host keys and then fingerprint them.
 
-The next step is to log into the device via ssh:
+    Returns a sequence of (key-type, fingerprint) pairs.
+    """
+    config = run_command(['sshd', '-T'])
+    if config['status'] != 0:
+        log.debug("sshd -T failed %r", config['err'])
+        return []
+    keyfiles = []
+    for line in config['output'].splitlines():
+        if line.startswith('hostkey '):
+            keyfiles.append(line.split(None, 1)[1])
+    info = []
+    for keyfile in keyfiles:
+        result = run_command(['ssh-keygen', '-lf', keyfile])
+        if result['status'] != 0:
+            log.debug("ssh-keygen -lf %s failed %r", keyfile, result['err'])
+            continue
+        parts = result['output'].strip().split()
+        length, fingerprint, host, keytype = parts
+        keytype = keytype.strip('()')
+        info.append((keytype, fingerprint))
+    return info
 
-{sshcommands}
-These keys can be used to log in:
 
-{sshkeys}
-Once you've logged in, you can optionally set a password by running
-"sudo passwd $USER". After you've set a password, you can also use it
-to log in here.
+host_keys_intro = """
+The host key fingerprints are:
 
-You can explore snappy core with snap --help.
 """
 
-def write_login_details(fp, realname, username, ips, fingerprints):
-    sshcommands = ""
+host_key_tmpl = """\
+    {keytype:{width}} {fingerprint}
+"""
+
+single_host_key_tmpl = """\
+The {keytype} host key fingerprints is:
+    {fingerprint}
+"""
+
+
+def host_key_info():
+    fingerprints = host_key_fingerprints()
+    if len(fingerprints) == 1:
+        [(keytype, fingerprint)] = fingerprints
+        return single_host_key_tmpl.format(keytype=keytype, fingerprint=fingerprint)
+    lines = [host_keys_intro]
+    longest_type = max([len(keytype) for keytype, _ in fingerprints])
+    for keytype, fingerprint in fingerprints:
+        lines.append(host_key_tmpl.format(keytype=keytype, fingerprint=fingerprint, width=longest_type))
+    return "".join(lines)
+
+login_details_tmpl = """\
+Ubuntu Core 16 on {first_ip} ({tty_name})
+{host_key_info}
+To login:
+{sshcommands}
+Personalize your account at https://login.ubuntu.com.
+"""
+
+def write_login_details(fp, username, ips):
+    sshcommands = "\n"
     for ip in ips:
         sshcommands += "    ssh %s@%s\n"%(username, ip)
-    sshkeys = ""
-    for fingerprint in fingerprints:
-        sshkeys += "    " + fingerprint + "\n"
-    fp.write(login_details_tmpl.format(realname=realname, username=username, sshcommands=sshcommands, sshkeys=sshkeys))
+    tty_name = os.ttyname(0)[5:] # strip off the /dev/
+    fp.write(login_details_tmpl.format(
+        sshcommands=sshcommands, host_key_info=host_key_info(), tty_name=tty_name, first_ip=ips[0]))
 
 def write_login_details_standalone():
     owner = get_device_owner()
     if owner is None:
-        # Nothing much we can do :/
-        print("No device owner details found")
+        print("No device owner details found.")
         return 0
     from probert import network
     from subiquitycore.models.network import NETDEV_IGNORED_IFACE_NAMES, NETDEV_IGNORED_IFACE_TYPES
-    import ipaddress
     import operator
-    import socket
     observer = network.UdevObserver()
     observer.start()
     ips = []
@@ -90,16 +130,18 @@ def write_login_details_standalone():
             continue
         if l.name in NETDEV_IGNORED_IFACE_NAMES:
             continue
-        ips.extend([str(ipaddress.IPv4Interface(a).ip) for a in l.ip.get(socket.AF_INET, [])])
-        ips.extend([str(ipaddress.IPv6Interface(a).ip) for a in l.ip.get(socket.AF_INET6, [])])
-    key_file = os.path.join(owner['homedir'], ".ssh/authorized_keys")
-    fingerprints = run_command(['ssh-keygen', '-lf', key_file])['output'].replace('\r', '').splitlines()
-    write_login_details(sys.stdout, owner['realname'], owner['username'], ips, fingerprints)
+        for _, addr in sorted(l.addresses.items()):
+            if addr.scope == "global":
+                ips.append(addr.ip)
+    write_login_details(sys.stdout, owner['username'], ips)
     return 0
 
 
-class IdentityController(BaseIdentityController):
-    identity_view = IdentityView
+class IdentityController(BaseController):
+
+    def __init__(self, common):
+        super().__init__(common)
+        self.model = IdentityModel(self.opts)
 
     def default(self):
         title = "Profile setup"
@@ -107,7 +149,7 @@ class IdentityController(BaseIdentityController):
         footer = ""
         self.ui.set_header(title, excerpt)
         self.ui.set_footer(footer, 40)
-        self.ui.set_body(self.identity_view(self.model, self, self.opts, self.loop))
+        self.ui.set_body(IdentityView(self.model, self, self.opts, self.loop))
         device_owner = get_device_owner()
         if device_owner is not None:
             self.model.add_user(device_owner)
@@ -122,7 +164,6 @@ class IdentityController(BaseIdentityController):
                 'username': email,
                 }
             self.model.add_user(result)
-            ssh_keys = subprocess.getoutput('ssh-add -L').splitlines()
             login_details_path = '.subiquity/login-details.txt'
         else:
             self.ui.frame.body.progress.set_text("Contacting store...")
@@ -138,24 +179,15 @@ class IdentityController(BaseIdentityController):
                     'realname': email,
                     'username': data['username'],
                     }
-                ssh_keys = data['ssh-keys']
                 os.makedirs('/run/console-conf', exist_ok=True)
                 login_details_path = '/run/console-conf/login-details.txt'
                 self.model.add_user(result)
-        log.debug('ssh_keys %s', ssh_keys)
-        fingerprints = []
-        for key in ssh_keys:
-            keygen_result = subprocess.Popen(['ssh-keygen', '-lf', '-'], stdin=subprocess.PIPE, stdout=subprocess.PIPE)
-            fingerprint, err = keygen_result.communicate(key.encode('utf-8'))
-            fingerprints.append(fingerprint.decode('utf-8', 'replace').replace('\r', '').strip())
-        self.model.user.fingerprints = fingerprints
-        log.debug('fingerprints %s', fingerprints)
         ips = []
         net_model = self.controllers['Network'].model
         for dev in net_model.get_all_netdevs():
-            ips.extend(dev.actual_ip_addresses)
+            ips.extend(dev.actual_global_ip_addresses)
         with open(login_details_path, 'w') as fp:
-            write_login_details(fp, result['realname'], result['username'], ips, fingerprints)
+            write_login_details(fp, result['username'], ips)
         self.login()
 
     def cancel(self):
@@ -178,6 +210,6 @@ class IdentityController(BaseIdentityController):
     def login_done(self):
         if not self.opts.dry_run:
             # stop the console-conf services (this will kill the current process).
-            disable_first_boot_service()
+            disable_console_conf()
 
         self.signal.emit_signal('quit')
