@@ -22,11 +22,16 @@ Provides network device listings and extended network information
 import logging
 import textwrap
 
-from urwid import (ListBox, Pile,
-                   Text, Columns, Overlay,
-                   LineBox, ProgressBar, WidgetWrap)
+from urwid import (
+    LineBox,
+    Overlay,
+    ProgressBar,
+    Text,
+    WidgetWrap,
+    )
 
 from subiquitycore.ui.buttons import cancel_btn, menu_btn, done_btn
+from subiquitycore.ui.container import Columns, ListBox, Pile
 from subiquitycore.ui.utils import Padding, Color
 from subiquitycore.view import BaseView
 
@@ -97,7 +102,7 @@ def _build_gateway_ip_info_for_version(dev, version):
             p.extend(_format_address_list("Currently has address%s:", actual_ip_addresses))
         return p
     elif actual_ip_addresses:
-        return _format_address_list("IPv%s is not configured but has address%%s:"%(version,), actual_ip_addresses)
+        return _format_address_list("Has no IPv%s configuration, currently has address%%s:"%(version,), actual_ip_addresses)
     else:
         return [Text("IPv%s is not configured"%(version,))]
 
@@ -124,26 +129,9 @@ class NetworkView(BaseView):
         self.lb.set_focus(4)  # _build_buttons
         super().__init__(self.lb)
 
-    def show_overlay(self, overlay_widget):
-        self.orig_w = self._w
-        self._w = Overlay(top_w=overlay_widget,
-                          bottom_w=self._w,
-                          align='center',
-                          width=('relative', 60),
-                          min_width=80,
-                          valign='middle',
-                          height='pack')
-
-    def remove_overlay(self, overlay_widget):
-        # urwid note: we could also get orig_w as
-        # self._w.contents[0][0], but this is clearer:
-        self._w = self.orig_w
-
     def _build_buttons(self):
-        cancel = Color.button(cancel_btn(on_press=self.cancel),
-                              focus_map='button focus')
-        done = Color.button(done_btn(on_press=self.done),
-                            focus_map='button focus')
+        cancel = Color.button(cancel_btn(on_press=self.cancel))
+        done = Color.button(done_btn(on_press=self.done))
         self.default_focus = done
 
         buttons = [done, cancel]
@@ -167,9 +155,8 @@ class NetworkView(BaseView):
             col_2 = []
 
             col_1.append(
-                Color.info_major(
-                    menu_btn(label=dev.name, on_press=self.on_net_dev_press),
-                    focus_map='button focus'))
+                Color.menu_button(
+                    menu_btn(label=dev.name, on_press=self.on_net_dev_press)))
 
             if dev.type == 'wlan':
                 col_2.extend(_build_wifi_info(dev))
@@ -243,8 +230,7 @@ class NetworkView(BaseView):
                 Color.menu_button(
                     menu_btn(label=opt,
                              on_press=self.additional_menu_select,
-                             user_data=sig),
-                    focus_map='button focus'))
+                             user_data=sig)))
 
         from urwid import Padding
         buttons = [ Padding(button, align='left', width=max_btn_len + 6) for button in buttons ]
